@@ -2,6 +2,20 @@
 ###
 ### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 
 createConLin <-
     function(fixed, data = sys.frame(sys.parent()),
@@ -128,14 +142,14 @@ simulate.lme <-
             aMs <- nlminb(c(coef(lmeSt)),
                function(lmePars) -logLik(lmeSt, lmePars),
                control = list(iter.max = control$msMaxIter,
-               eval.max = control$msMaxEval, 
+               eval.max = control$msMaxEval,
                trace = control$msVerbose))
             c(info = aMs$flags[1], logLik = -aMs$value)
         }
 
     if(!exists(".Random.seed", envir = .GlobalEnv))
         runif(1)		     # initialize the RNG if necessary
-    RNGstate <- .Random.seed
+    RNGstate <- get(".Random.seed", envir = .GlobalEnv)
     set.seed(seed)
 
     if (inherits(object, "lme")) {      # given as an lme object
