@@ -1,11 +1,10 @@
-/* $Id: nlmefit.h,v 1.6 2001/10/15 17:19:12 bates Exp $
-
+/*
    header file for the nlme package
 
    Copyright 1999-2001 Saikat DebRoy <saikat@stat.wisc.edu>,
                        Douglas Bates <bates@stat.wisc.edu>
 
-   This file is part of the nlme library for R and related languages
+   This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
    License, version 2, or at your option, any later version,
    incorporated herein by reference.
@@ -16,10 +15,9 @@
    PURPOSE.  See the GNU General Public License for more
    details.
 
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
  
 */
 
